@@ -56,7 +56,7 @@ class RedisConfig:
 class PythonSearchConfiguration(EntriesGroup):
     """
     The main configuration of Python Search
-    Everything to customize about the application should be tunneled through this clas
+    Everything to customize about the application is configurable via code through this class
     """
 
     APPLICATION_TITLE = "SearchPythonSearch"
@@ -78,9 +78,9 @@ class PythonSearchConfiguration(EntriesGroup):
             self.aggregate_commands(entries_groups)
 
         if supported_features:
-            self.supported_features = supported_features
+            self.supported_features: FeaturesSupport = supported_features
         else:
-            self.supported_features = FeaturesSupport.default()
+            self.supported_features: FeaturesSupport = FeaturesSupport.default()
 
 
 class ConfigurationLoader:
@@ -90,26 +90,38 @@ class ConfigurationLoader:
 
     def load_config(self) -> PythonSearchConfiguration:
 
-        env_name = "PS_ENTRIES_HOME"
-
-        if env_name not in os.environ:
-            raise Exception(f"{env_name} must be set to load the config dynamically")
-
-        logging.debug(f"Env: {env_name}={os.environ[env_name]}")
-        folder = os.environ[env_name]
-
-        config_location = os.path.join(folder, "entries_main.py")
+        folder = self.get_project_root()
+        config_location = f"{folder}/entries_main.py"
 
         if not os.path.exists(config_location):
             raise Exception(f"Could not find config file {config_location}")
 
         import sys
 
-        sys.path.append(folder)
+        sys.path.insert(0, folder)
         from entries_main import config
 
         return config
 
+    def get_project_root(self):
+        env_name = "PS_ENTRIES_HOME"
+        current_project_location = os.environ['HOME'] + '/.config/python_search/current_project'
+
+        folder = None
+
+        if env_name in os.environ:
+            logging.debug(f"Env exists and takes precedence: {env_name}={os.environ[env_name]}")
+            folder = os.environ[env_name]
+
+        if os.path.isfile(current_project_location):
+            with open(current_project_location) as f:
+                folder = f.readlines()[0].strip()
+
+        if not folder:
+            raise Exception(f"Either {current_project_location} or {env_name} must be set to find entries")
+        return folder
+
+
     def load_entries(self):
         config = self.load_config()
         return config.commands
